@@ -1,16 +1,16 @@
 .cr.data.frame <-
-function(x, miss, show.n, digits.d,
-         heat.map, fill.low, fill.hi, main, bottom, right, 
+function(x, miss, show_n, digits_d,
+         heat_map, fill_low, fill_hi, main, bottom, right, 
          pdf, width, height, ...)  {
 
-  if (!is.null(digits.d) && digits.d<1) {
+  if (!is.null(digits_d) && digits_d<1) {
     cat("\n"); stop(call.=FALSE, "\n","------\n",      
-        "\n>>> digits d is ", digits.d,  " and must be at least 1.\n")
+        "\n>>> digits d is ", digits_d,  " and must be at least 1.\n")
   }
 
-  if (miss == "pairwise") miss.type <- "pairwise.complete.obs"
-  else if (miss == "listwise") miss.type <- "complete.obs"
-  else if (miss == "everything") miss.type <- "everything"
+  if (miss == "pairwise") miss_type <- "pairwise.complete.obs"
+  else if (miss == "listwise") miss_type <- "complete.obs"
+  else if (miss == "everything") miss_type <- "everything"
 
   max.digits <- 0
   dig.warning <- FALSE
@@ -24,14 +24,14 @@ function(x, miss, show.n, digits.d,
     options(xname = x.name)  # sets for each variable   WHY???
 
     #nu <- length(unique(na.omit(x[,i])))
-    #if (.is.num.cat(x[,i], n.cat)) {
+    #if (.is.num.cat(x[,i], n_cat)) {
       #i.not <- i.not + 1
       #not.num[i.not] <- i
       #cat("\n")
       #cat("\n>>> Note:", x.name,  "is technically numeric, but only has ", 
-          #nu, "<= n.cat =", n.cat, " levels,\n",
+          #nu, "<= n_cat =", n_cat, " levels,\n",
          #"      so treat as a categorical variable.\n",
-         #"    To obtain the correlations decrease  n.cat  to specify a",
+         #"    To obtain the correlations decrease  n_cat  to specify a",
          #"lower number\n",
          #"      of unique values, such as with the function: style\n",
          #"    Perhaps make this variable a factor with the R factor function.\n")
@@ -42,15 +42,15 @@ function(x, miss, show.n, digits.d,
       not.num[i.not] <- i
     }
 
-    if (is.null(digits.d)) {
-      dig.dec <- .max.dd(x[,i]) + 1 
-      if (dig.dec < 2) dig.dec <- 2
-      if (dig.dec > max.digits  &&  !dig.warning) max.digits <- dig.dec
-      if (dig.dec > 10  &&  !dig.warning) {
-        cat("\nThese data values contain ", dig.dec, " decimal digits. To enhance\n",
+    if (is.null(digits_d)) {
+      digits_d <- .max.dd(x[,i]) + 1 
+      if (digits_d < 2) digits_d <- 2
+      if (digits_d > max.digits  &&  !dig.warning) max.digits <- digits_d
+      if (digits_d > 10  &&  !dig.warning) {
+        cat("\nThese data values contain ", digits_d, " decimal digits. To enhance\n",
             "the readability of the output, only 4 decimal digits are\n",
-            "displayed.  To customize this setting, use the digits.d  parameter.\n",
-            "Example for Variables Y and X:  > cr(Y, by=X, digits.d=3)\n\n",
+            "displayed.  To customize this setting, use the digits_d  parameter.\n",
+            "Example for Variables Y and X:  > cr(Y, by=X, digits_d=3)\n\n",
             sep="")
         dig.warning <- TRUE
         max.digits <- 4
@@ -73,8 +73,8 @@ function(x, miss, show.n, digits.d,
     }
   }
   
-  if (!is.null(digits.d)) max.digits <- digits.d
-  crs <- round(cor(x, use=miss.type, ...), digits=max.digits)  # cor matrix
+  if (!is.null(digits_d)) max.digits <- digits_d
+  crs <- round(cor(x, use=miss_type, ...), digits=max.digits)  # cor matrix
 
   n.vars <- nrow(crs)
   tx[length(tx)+1] <- ""
@@ -108,14 +108,14 @@ function(x, miss, show.n, digits.d,
       tx[length(tx)+1] <- paste("\n>>> No missing data")
     else {
       .ss.factor(as.vector(n), brief=TRUE, x.name=" ")  # x.name KLUDGE
-      if (n.vars <= 15  ||  show.n) {
+      if (n.vars <= 15  ||  show_n) {
         txn <- .prntbl(n, 2, cc=" ")
         for (i in 1:length(txn)) tx[length(tx)+1] <- txn[i]
       }
       else
         tx[length(tx)+1] <- paste("To view the sample size for each ",
           "correlation, re-run the\n",
-          "analysis with show.n=TRUE\n", sep="")
+          "analysis with show_n=TRUE\n", sep="")
     }
   }  # end pairwise
 
@@ -141,7 +141,7 @@ function(x, miss, show.n, digits.d,
   txc <- tx
 
 
-  if (heat.map  ||  pdf) {
+  if (heat_map  ||  pdf) {
 
     # heat map
     if (!pdf) {
@@ -152,60 +152,60 @@ function(x, miss, show.n, digits.d,
       }
     }
     else { 
-      pdf.file <- "Cor_HeatMap.pdf"
-      pdf(file=pdf.file, width=width, height=height)
+      pdf_file <- "Cor_HeatMap.pdf"
+      pdf(file=pdf_file, width=width, height=height)
     }
 
     # NEED to integrate into .corcolors
-    if (is.null(fill.low)  &&  is.null(fill.hi)) {      
+    if (is.null(fill_low)  &&  is.null(fill_hi)) {      
       if (getOption("theme") %in% c("colors", "dodgerblue", "blue", 
                                     "lightbronze")) {
-        fill.low <- "rusts"
-        fill.hi <- "blues"
+        fill_low <- "rusts"
+        fill_hi <- "blues"
       }
       else if (getOption("theme") %in% c("darkred", "red", "rose")) {
-        fill.low <- "turquoises" 
-        fill.hi <- "reds"
+        fill_low <- "turquoises" 
+        fill_hi <- "reds"
       }
       else if (getOption("theme") %in% c("darkgreen", "green")) {
-        fill.low <- "violets" 
-        fill.hi <- "greens"
+        fill_low <- "violets" 
+        fill_hi <- "greens"
       }
       else if (getOption("theme") %in% c("gold", "brown", "sienna")) {
-        fill.low <- "blues" 
-        fill.hi <- "browns"
+        fill_low <- "blues" 
+        fill_hi <- "browns"
       }
       else if (getOption("theme") %in% c("gray", "white")) {
-        fill.low <- "white"
-        fill.hi <- "black"
+        fill_low <- "white"
+        fill_hi <- "black"
       }
     }
 
-    else if (is.null(fill.low) || is.null(fill.hi)) { 
-      fill.low <- "white"
-      fill.hi <- "gray20"
+    else if (is.null(fill_low) || is.null(fill_hi)) { 
+      fill_low <- "white"
+      fill_hi <- "gray20"
     }
 
-    # fill.low and fill.hi "blues", etc, then divergent, else sequential`
+    # fill_low and fill_hi "blues", etc, then divergent, else sequential`
 #   if (getOption("theme") %in% c("gray", "white"))
 #     hmcols <- getColors("grays", "grays", l=c(10,100))
 #   else
-      hmcols <- getColors(fill.low, fill.hi, l=c(10,90))
-#   hmcols <- colorRampPalette(c(fill.low, fill.hi))(256)
+      hmcols <- getColors(fill_low, fill_hi, l=c(10,90))
+#   hmcols <- colorRampPalette(c(fill_low, fill_hi))(256)
 
-    axis.x.cex <- ifelse(is.null(getOption("axis.x.cex")),
-        getOption("axis.cex"), getOption("axis.x.cex"))
-    axis.y.cex <- ifelse(is.null(getOption("axis.y.cex")),
-        getOption("axis.cex"), getOption("axis.y.cex"))
+    axis_x_cex <- ifelse(is.null(getOption("axis_x_cex")),
+        getOption("axis_cex"), getOption("axis_x_cex"))
+    axis_y_cex <- ifelse(is.null(getOption("axis_y_cex")),
+        getOption("axis_cex"), getOption("axis_y_cex"))
 
     heatmap(crs[1:ncol(crs),1:ncol(crs)], Rowv=NA, Colv="Rowv", symm=TRUE,
       col=hmcols, margins=c(bottom, right), main=main,
-      cexRow=axis.x.cex, cexCol=axis.y.cex)
+      cexRow=axis_x_cex, cexCol=axis_y_cex)
 
 
     if (pdf) {  # terminate pdf graphics
       dev.off()
-      .showfile(pdf.file, "heat map")
+      .showfile(pdf_file, "heat map")
       cat("\n\n")
     }
   }
