@@ -1,4 +1,4 @@
 ss.brief <-
 function(..., brief=TRUE)
 
-ss(..., brief=TRUE)
+  SummaryStats(..., brief=TRUE)
